@@ -985,7 +985,12 @@ def set_bitmap_labels(btn, disabled=True, focus=None, pressed=True):
 
     # Disabled
     if disabled:
-        btn.SetBitmapDisabled(get_bitmap_disabled(bitmap))
+        try:
+            btn.SetBitmapDisabled(get_bitmap_disabled(bitmap))
+        except wx._core.wxAssertionError:
+            # must set normal bitmap first, fixes #507
+            btn.SetBitmapLabel(bitmap)
+            btn.SetBitmapDisabled(get_bitmap_disabled(bitmap))
 
     # Focus/Hover
     if sys.platform != "darwin" and focus is not False:
@@ -1056,6 +1061,7 @@ class PathDialogBase(wx.Dialog):
     def OnDestroy(self, event):
         self.filedialog.Destroy()
         event.Skip()
+        return 0
 
     def Show(self, show=True):
         self._isshown = show
@@ -1152,7 +1158,7 @@ wx.ScrolledWindow = ScrolledWindow
 ScrolledPanel.ScrollChildIntoView = ScrolledWindow.ScrollChildIntoView
 
 
-class GenButton(object):
+class GenButton:
     """A generic button, based on wx.lib.buttons.GenButton.
 
     Fixes wx.lib.buttons.ThemedGenButton not taking into account backgroun
@@ -1608,7 +1614,7 @@ if not hasattr(PlateButton, "_SetState"):
     PlateButton._SetState = PlateButton.SetState
 
 
-class TempXmlResource(object):
+class TempXmlResource:
     _temp = None
 
     def __init__(self, xmlpath):
